# PixelToBinary
A modular python library for creating Binary Images and Binary Movies, easily.

...
## Installation
Run the following line at your favorite terminal:

```python
pip install PixelToBinary
```

...
## Usage

...
## Contributing 

To install PixelToBinary, along with the tools you need to develop and run tests, run the folowing in your virtual environment:
```bash
$ pip install -e .[dev]
```
